/**
 * @file bugsample.c
 *
 * Sample of 3 bugs.
 *
 * Sample of several bugs:
 * - "name" directive ignored in structure
 * - File List and Data Structure pages do not include brief descriptions.
 * - No warning for undocumented function.
 *
 * These bugs are all seen in 1.4.3, 1.4.1 shows none of these problems.
 */


/**
 *
 *   State of a transmitted or received sequence.
 *
 *   @ingroup group_fcdrv_seq_internal
 */
struct _fcdrv_seq_t {
	/** @name Basic Identity */
	seq_id_t		 seq_id;	/**< Sequence ID (FC official?) */
	unsigned int	 seq_class;	/**< Class of service */

	/** @name Transmission/Receipt State */

	/**
	 * Head of a linked list of frames themselves (Rx or Tx),
	 * sorted by ascending seq_cnt.
	 */
	fcdrv_frm_queue_t	*seq_frm_list;
	fcdrv_seq_state_t	 seq_state;	/**< Current sequence state */

	/** @name Timestamps and Timeout */

	/**
	 * Caller-specified timeout, or FC_DEFAULT_TO, which indicates a default
	 * set of timeouts (reliable transport and non-reliable have different
	 * defaults, see @ref fcdrv_seq_check_timeout).
	 */
	unsigned int	 seq_to;

	/**
	 * Amount of time this sequence has gone without a received frame or ACK.
	 * (Are units jiffies, or milliseconds?)
	 */
	unsigned int	 seq_to_cnt;
};

/* This is not officially documented */
void
fcdrv_seq_set_state(fcdrv_seq_t *seq, fcdrv_seq_state_t new_value)
{
	seq->seq_state = new_value;
}
